@@ -43,8 +43,8 @@ const signalCatalog = new SignalCatalog(stack, 'SignalCatalog', {
   table,
   role,
   nodes: [
-    new SignalCatalogBranch('Vehicle', 'Vehicle'),
-    new SignalCatalogSensor('EngineTorque', 'Vehicle.EngineTorque', 'DOUBLE'),
+    new SignalCatalogBranch('Vehicle'),
+    new SignalCatalogSensor('Vehicle.EngineTorque', 'DOUBLE'),
   ],
 });
 
@@ -54,7 +54,7 @@ const model_a = new VehicleModel(stack, 'ModelA', {
   description: 'Model A vehicle',
   networkInterfaces: [new CanVehicleInterface('1', 'vcan0')],
   signals: [
-    new CanVehicleSignal('EngineTorque', 'Vehicle.EngineTorque', '1',
+    new CanVehicleSignal('Vehicle.EngineTorque', '1',
       401, // messageId
       1.0, // factor
       true, // isBigEndian
@@ -66,7 +66,7 @@ const model_a = new VehicleModel(stack, 'ModelA', {
 });
 
 const vin100 = new Vehicle(stack, 'vin100', {
-  vehicleId: 'vin100',
+  vehicleName: 'vin100',
   vehicleModel: model_a,
   createIotThing: true
 });
@@ -622,7 +622,6 @@ class SignalCatalogSensor(
 ):
     def __init__(
         self,
-        name: builtins.str,
         fully_qualified_name: builtins.str,
         data_type: builtins.str,
         unit: typing.Optional[builtins.str] = None,
@@ -631,7 +630,6 @@ class SignalCatalogSensor(
         description: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param name: -
         :param fully_qualified_name: -
         :param data_type: -
         :param unit: -
@@ -639,7 +637,7 @@ class SignalCatalogSensor(
         :param max: -
         :param description: -
         '''
-        jsii.create(self.__class__, self, [name, fully_qualified_name, data_type, unit, min, max, description])
+        jsii.create(self.__class__, self, [fully_qualified_name, data_type, unit, min, max, description])
 
 
 class TimeBasedCollectionScheme(
@@ -667,20 +665,20 @@ class Vehicle(
         id: builtins.str,
         *,
         create_iot_thing: builtins.bool,
-        vehicle_id: builtins.str,
         vehicle_model: "VehicleModel",
+        vehicle_name: builtins.str,
     ) -> None:
         '''
         :param scope: -
         :param id: -
         :param create_iot_thing: 
-        :param vehicle_id: 
         :param vehicle_model: 
+        :param vehicle_name: 
         '''
         props = VehicleProps(
             create_iot_thing=create_iot_thing,
-            vehicle_id=vehicle_id,
             vehicle_model=vehicle_model,
+            vehicle_name=vehicle_name,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -690,16 +688,16 @@ class Vehicle(
     def arn(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "arn"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="vehicleId")
-    def vehicle_id(self) -> builtins.str:
-        return typing.cast(builtins.str, jsii.get(self, "vehicleId"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="vehicleModel")
     def vehicle_model(self) -> "VehicleModel":
         return typing.cast("VehicleModel", jsii.get(self, "vehicleModel"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="vehicleName")
+    def vehicle_name(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "vehicleName"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="certificateArn")
     def certificate_arn(self) -> typing.Optional[builtins.str]:
@@ -891,8 +889,8 @@ class VehicleModelProps:
     jsii_struct_bases=[],
     name_mapping={
         "create_iot_thing": "createIotThing",
-        "vehicle_id": "vehicleId",
         "vehicle_model": "vehicleModel",
+        "vehicle_name": "vehicleName",
     },
 )
 class VehicleProps:
@@ -900,19 +898,19 @@ class VehicleProps:
         self,
         *,
         create_iot_thing: builtins.bool,
-        vehicle_id: builtins.str,
         vehicle_model: VehicleModel,
+        vehicle_name: builtins.str,
     ) -> None:
         '''Interface.
 
         :param create_iot_thing: 
-        :param vehicle_id: 
         :param vehicle_model: 
+        :param vehicle_name: 
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "create_iot_thing": create_iot_thing,
-            "vehicle_id": vehicle_id,
             "vehicle_model": vehicle_model,
+            "vehicle_name": vehicle_name,
         }
 
     @builtins.property
@@ -921,18 +919,18 @@ class VehicleProps:
         assert result is not None, "Required property 'create_iot_thing' is missing"
         return typing.cast(builtins.bool, result)
 
-    @builtins.property
-    def vehicle_id(self) -> builtins.str:
-        result = self._values.get("vehicle_id")
-        assert result is not None, "Required property 'vehicle_id' is missing"
-        return typing.cast(builtins.str, result)
-
     @builtins.property
     def vehicle_model(self) -> VehicleModel:
         result = self._values.get("vehicle_model")
         assert result is not None, "Required property 'vehicle_model' is missing"
         return typing.cast(VehicleModel, result)
 
+    @builtins.property
+    def vehicle_name(self) -> builtins.str:
+        result = self._values.get("vehicle_name")
+        assert result is not None, "Required property 'vehicle_name' is missing"
+        return typing.cast(builtins.str, result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -1005,7 +1003,6 @@ class CanVehicleSignal(
 ):
     def __init__(
         self,
-        name: builtins.str,
         fully_qualified_name: builtins.str,
         interface_id: builtins.str,
         message_id: jsii.Number,
@@ -1017,7 +1014,6 @@ class CanVehicleSignal(
         start_bit: jsii.Number,
     ) -> None:
         '''
-        :param name: -
         :param fully_qualified_name: -
         :param interface_id: -
         :param message_id: -
@@ -1028,7 +1024,7 @@ class CanVehicleSignal(
         :param offset: -
         :param start_bit: -
         '''
-        jsii.create(self.__class__, self, [name, fully_qualified_name, interface_id, message_id, factor, is_big_endian, is_signed, length, offset, start_bit])
+        jsii.create(self.__class__, self, [fully_qualified_name, interface_id, message_id, factor, is_big_endian, is_signed, length, offset, start_bit])
 
 
 class SignalCatalogBranch(
@@ -1038,16 +1034,14 @@ class SignalCatalogBranch(
 ):
     def __init__(
         self,
-        name: builtins.str,
         fully_qualified_name: builtins.str,
         description: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param name: -
         :param fully_qualified_name: -
         :param description: -
         '''
-        jsii.create(self.__class__, self, [name, fully_qualified_name, description])
+        jsii.create(self.__class__, self, [fully_qualified_name, description])
 
 
 __all__ = [
