@@ -19,7 +19,7 @@ def on_create(event):
     client=boto3.client('iotfleetwise')
     
     response = client.create_campaign(
-      campaignName = props['campaign_name'],
+      name = props['name'],
       signalCatalogArn = props['signal_catalog_arn'],
       targetArn = props['target_arn'],
       collectionScheme = json.loads(props['collection_scheme']),
@@ -31,20 +31,20 @@ def on_create(event):
         retry_count = 10;
         delay = 2;
         while retry_count > 1:
-            print(f"waiting for campaign {props['campaign_name']} to be created")
-            response = client.get_campaign(campaignName = props['campaign_name'])
+            print(f"waiting for campaign {props['name']} to be created")
+            response = client.get_campaign(name = props['name'])
             print(f"get_campaign response {response}")
             if response['status'] == "WAITING_FOR_APPROVAL":
                 break
             time.sleep(delay)
             retry_count = retry_count - 1            
-        print(f"approving the campaign {props['campaign_name']}")
+        print(f"approving the campaign {props['name']}")
         response = client.update_campaign(
-          campaignName = props['campaign_name'],
+          name = props['name'],
           action = 'APPROVE'
         )
         print(f"update_campaign response {response}")
-    return { 'PhysicalResourceId': props['campaign_name'] }
+    return { 'PhysicalResourceId': props['name'] }
 
 def on_update(event):
     physical_id = event["PhysicalResourceId"]
@@ -56,11 +56,11 @@ def on_update(event):
 def on_delete(event):
     physical_id = event["PhysicalResourceId"]
     props = event["ResourceProperties"]
-    print(f"delete resource {props['campaign_name']} {physical_id}")
+    print(f"delete resource {props['name']} {physical_id}")
     client=boto3.client('iotfleetwise')
 
     response = client.delete_campaign(
-      campaignName = props['campaign_name'],
+      name = props['name'],
     )
     print(f"delete_campaign response {response}")
 
