@@ -61,8 +61,8 @@ export class IntegTesting {
       role,
       description: 'my signal catalog',
       nodes: [
-        new ifw.SignalCatalogBranch('Vehicle', 'Vehicle'),
-        new ifw.SignalCatalogSensor('EngineTorque', 'Vehicle.EngineTorque', 'DOUBLE'),
+        new ifw.SignalCatalogBranch('Vehicle'),
+        new ifw.SignalCatalogSensor('Vehicle.EngineTorque', 'DOUBLE'),
       ],
     });
 
@@ -72,7 +72,7 @@ export class IntegTesting {
       description: 'Model A vehicle',
       networkInterfaces: [new ifw.CanVehicleInterface('1', 'vcan0')],
       signals: [
-        new ifw.CanVehicleSignal('EngineTorque', 'Vehicle.EngineTorque', '1',
+        new ifw.CanVehicleSignal('Vehicle.EngineTorque', '1',
           401, // messageId
           1.0, // factor
           true, // isBigEndian
@@ -84,7 +84,7 @@ export class IntegTesting {
     });
 
     const vin100 = new ifw.Vehicle(stack, 'vin100', {
-      vehicleId: 'vin100',
+      vehicleName: 'vin100',
       vehicleModel: model_a,
       createIotThing: true,
     });
@@ -215,7 +215,7 @@ export class IntegTesting {
     ./tools/configure-fwe.sh \
       --input-config-file "configuration/static-config.json" \
       --output-config-file "/etc/aws-iot-fleetwise/config-0.json" \
-      --vehicle-id vin100 \
+      --vehicle-name vin100 \
       --endpoint-url "${vin100.endpointAddress}" \
       --topic-prefix '$aws/iotfleetwise/' \
       --can-bus0 "vcan0"
